@@ -113,24 +113,65 @@ class Printer:
     @staticmethod
     def from_dict(data):
         """Return Printer object from IPP response."""
-        marker_colors = data.get("marker-colors", [])
-        marker_levels = data.get("marker-levels", [])
-        marker_high_levels = data.get("marker-high-levels", [])
-        marker_low_levels = data.get("marker-low-levels", [])
-        marker_types = data.get("marker-types", [])
-        markers = [
-            Marker(
-                marker_id=marker_id,
-                marker_type=marker_types[marker_id],
-                name=marker,
-                color=marker_colors[marker_id],
-                level=marker_levels[marker_id],
-                high_level=marker_high_levels[marker_id],
-                low_level=marker_low_levels[marker_id],
-            )
-            for marker_id, marker in enumerate(data.get("marker-names", {}))
-        ]
-        markers.sort(key=lambda x: x.name)
+        markers = []
+        mlen = 0
+        marker_colors = []
+        marker_levels = []
+        marker_types = []
+        marker_highs = []
+        marker_lows = []
+
+        marker_names = None
+        if isinstance(data.get("marker-names"), List):
+            marker_names = data["marker-names"]
+            mlen = len(marker_names)
+
+            for k in range(mlen):
+                marker_colors.append("")
+                marker_levels.append(-2)
+                marker_types.append("unknown")
+                marker_highs.append(100)
+                marker_lows.append(0)
+
+        if isinstance(data.get("marker-colors"), List):
+            for k, v in enumerate(data["marker-colors"]):
+                if k < mlen:
+                    marker_colors[k] = v
+
+        if isinstance(data.get("marker-levels"), List):
+            for k, v in enumerate(data["marker-levels"]):
+                if k < mlen:
+                    marker_levels[k] = v
+
+        if isinstance(data.get("marker-high-levels"), List):
+            for k, v in enumerate(data["marker-high-levels"]):
+                if k < mlen:
+                    marker_highs[k] = v
+
+        if isinstance(data.get("marker-low-levels"), List):
+            for k, v in enumerate(data["marker-low-levels"]):
+                if k < mlen:
+                    marker_lows[k] = v
+
+        if isinstance(data.get("marker-types"), List):
+            for k, v in enumerate(data["marker-types"]):
+                if k < mlen:
+                    marker_types[k] = v
+
+        if isinstance(marker_names, List) and mlen > 0:
+            markers = [
+                Marker(
+                    marker_id=marker_id,
+                    marker_type=marker_types[marker_id],
+                    name=marker_names[marker_id],
+                    color=marker_colors[marker_id],
+                    level=marker_levels[marker_id],
+                    high_level=marker_highs[marker_id],
+                    low_level=marker_lows[marker_id],
+                )
+                for marker_id in range(mlen)
+            ]
+            markers.sort(key=lambda x: x.name)
 
         return Printer(
             info=Info.from_dict(data), markers=markers, state=State.from_dict(data)
